Documentation
¶
Overview ¶
package v1alpha4 contains API Schema definitions for the schemas v1alpha4 API group +k8s:openapi-gen=true +k8s:deepcopy-gen=package,register +k8s:conversion-gen=github.com/schemahero/schemahero/pkg/apis/schemas +k8s:defaulter-gen=TypeMeta +groupName=schemas.schemahero.io
package v1alpha4 contains API Schema definitions for the schemas v1alpha4 API group +k8s:openapi-gen=true +k8s:deepcopy-gen=package,register +k8s:conversion-gen=github.com/schemahero/schemahero/pkg/apis/schemas +k8s:defaulter-gen=TypeMeta +groupName=schemas.schemahero.io
Index ¶
- Variables
- func Resource(resource string) schema.GroupResource
- type CassandraClusteringOrder
- type CassandraColumn
- type CassandraDataTypeSchema
- type CassandraField
- type CassandraTableProperties
- type CassandraTableSchema
- type Column
- type DataType
- type DataTypeList
- type DataTypeSchema
- type DataTypeSpec
- type DataTypeStatus
- type Migration
- type MigrationList
- type MigrationSpec
- type MigrationStatus
- type MysqlTableColumn
- type MysqlTableColumnAttributes
- type MysqlTableColumnConstraints
- type MysqlTableForeignKey
- type MysqlTableForeignKeyReferences
- type MysqlTableIndex
- type MysqlTableSchema
- type NotImplementedViewSchema
- type Phase
- type PostgresqlTableColumn
- type PostgresqlTableColumnAttributes
- type PostgresqlTableColumnConstraints
- type PostgresqlTableForeignKey
- type PostgresqlTableForeignKeyReferences
- type PostgresqlTableIndex
- type PostgresqlTableSchema
- type PostgresqlTableTrigger
- type RqliteTableColumn
- type RqliteTableColumnAttributes
- type RqliteTableColumnConstraints
- type RqliteTableForeignKey
- type RqliteTableForeignKeyReferences
- type RqliteTableIndex
- type RqliteTableSchema
- type SeedData
- type SeedDataRow
- type SeedDataValue
- type SqliteTableColumn
- type SqliteTableColumnAttributes
- type SqliteTableColumnConstraints
- type SqliteTableForeignKey
- type SqliteTableForeignKeyReferences
- type SqliteTableIndex
- type SqliteTableSchema
- type Table
- type TableList
- type TableSchema
- type TableSpec
- type TableStatus
- type TimescaleDBCompression
- type TimescaleDBHypertable
- type TimescaleDBRetention
- type TimescaleDBTableSchema
- type TimescaleDBViewSchema
- type View
- type ViewList
- type ViewSchema
- type ViewSpec
- type ViewStatus
Constants ¶
This section is empty.
Variables ¶
var ( // SchemeGroupVersion is group version used to register these objects SchemeGroupVersion = schema.GroupVersion{Group: "schemas.schemahero.io", Version: "v1alpha4"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: SchemeGroupVersion} // AddToScheme is required by pkg/client/... AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource is required by pkg/client/listers/...
Types ¶
type CassandraClusteringOrder ¶ added in v0.12.0
type CassandraClusteringOrder struct {
Column string `json:"column" yaml:"column"`
IsDescending *bool `json:"isDescending,omitempty" yaml:"isDescending,omitempty"`
}
func (*CassandraClusteringOrder) DeepCopy ¶ added in v0.12.0
func (in *CassandraClusteringOrder) DeepCopy() *CassandraClusteringOrder
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CassandraClusteringOrder.
func (*CassandraClusteringOrder) DeepCopyInto ¶ added in v0.12.0
func (in *CassandraClusteringOrder) DeepCopyInto(out *CassandraClusteringOrder)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CassandraColumn ¶ added in v0.12.0
type CassandraColumn struct {
Name string `json:"name" yaml:"name"`
Type string `json:"type" yaml:"type"`
IsStatic *bool `json:"isStatic,omitempty" yaml:"isStatic,omitempty"`
}
func (*CassandraColumn) DeepCopy ¶ added in v0.12.0
func (in *CassandraColumn) DeepCopy() *CassandraColumn
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CassandraColumn.
func (*CassandraColumn) DeepCopyInto ¶ added in v0.12.0
func (in *CassandraColumn) DeepCopyInto(out *CassandraColumn)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CassandraDataTypeSchema ¶ added in v0.12.0
type CassandraDataTypeSchema struct {
IsDeleted bool `json:"isDeleted,omitempty" yaml:"isDeleted,omitempty"`
Fields []*CassandraField `json:"fields,omitempty" yaml:"fields,omitempty"`
}
func (*CassandraDataTypeSchema) DeepCopy ¶ added in v0.12.0
func (in *CassandraDataTypeSchema) DeepCopy() *CassandraDataTypeSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CassandraDataTypeSchema.
func (*CassandraDataTypeSchema) DeepCopyInto ¶ added in v0.12.0
func (in *CassandraDataTypeSchema) DeepCopyInto(out *CassandraDataTypeSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CassandraField ¶ added in v0.12.0
type CassandraField struct {
Name string `json:"name" yaml:"name"`
Type string `json:"type" yaml:"type"`
}
func (*CassandraField) DeepCopy ¶ added in v0.12.0
func (in *CassandraField) DeepCopy() *CassandraField
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CassandraField.
func (*CassandraField) DeepCopyInto ¶ added in v0.12.0
func (in *CassandraField) DeepCopyInto(out *CassandraField)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CassandraTableProperties ¶ added in v0.12.0
type CassandraTableProperties struct {
BloomFilterFPChance string `json:"bloomFilterFPChance,omitempty" yaml:"bloomFilterFPChance,omitempty"`
Caching map[string]string `json:"caching,omitempty" yaml:"caching,omitempty"`
Comment string `json:"comment,omitempty" yaml:"comment,omitempty"`
Compaction map[string]string `json:"compaction,omitempty" yaml:"compaction,omitempty"`
Compression map[string]string `json:"compression,omitempty" yaml:"compression,omitempty"`
CRCCheckChance string `json:"crcCheckChance,omitempty" yaml:"crcCheckChance,omitempty"`
DCLocalReadRepairChance string `json:"dcLocalReadRepairChance,omitempty" yaml:"dcLocalReadRepairChance,omitempty"`
DefaultTTL *int `json:"defaultTTL,omitempty" yaml:"defaultTTL,omitempty"`
GCGraceSeconds *int `json:"gcGraceSeconds,omitempty" yaml:"gcGraceSeconds,omitempty"`
MaxIndexInterval *int `json:"maxIndexInterval,omitempty" yaml:"maxIndexInterval,omitempty"`
MemtableFlushPeriodMS *int `json:"memtableFlushPeriodMs,omitempty" yaml:"memtableFlushPeriodMs,omitempty"`
MinIndexInterval *int `json:"minIndexInterval,omitempty" yaml:"minIndexInterval,omitempty"`
ReadRepairChance string `json:"readRepairChance,omitempty" yaml:"readRepairChance,omitempty"`
SpeculativeRetry string `json:"speculativeRetry,omitempty" yaml:"speculativeRetry,omitempty"`
}
func (*CassandraTableProperties) DeepCopy ¶ added in v0.12.0
func (in *CassandraTableProperties) DeepCopy() *CassandraTableProperties
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CassandraTableProperties.
func (*CassandraTableProperties) DeepCopyInto ¶ added in v0.12.0
func (in *CassandraTableProperties) DeepCopyInto(out *CassandraTableProperties)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CassandraTableSchema ¶ added in v0.12.0
type CassandraTableSchema struct {
IsDeleted bool `json:"isDeleted,omitempty" yaml:"isDeleted,omitempty"`
PrimaryKey [][]string `json:"primaryKey,omitempty" yaml:"primaryKey,omitempty"`
ClusteringOrder *CassandraClusteringOrder `json:"clusteringOrder,omitempty" yaml:"clusteringOrder,omitempty"`
Columns []*CassandraColumn `json:"columns,omitempty" yaml:"columns,omitempty"`
Properties *CassandraTableProperties `json:"properties,omitempty" yaml:"properties,omitempty"`
}
func (*CassandraTableSchema) DeepCopy ¶ added in v0.12.0
func (in *CassandraTableSchema) DeepCopy() *CassandraTableSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CassandraTableSchema.
func (*CassandraTableSchema) DeepCopyInto ¶ added in v0.12.0
func (in *CassandraTableSchema) DeepCopyInto(out *CassandraTableSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Column ¶ added in v0.13.0
type Column struct {
Column string `json:"column" yaml:"column"`
Value SeedDataValue `json:"value" yaml:"value"`
}
func (*Column) DeepCopy ¶ added in v0.13.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Column.
func (*Column) DeepCopyInto ¶ added in v0.13.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DataType ¶ added in v0.12.0
type DataType struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec DataTypeSpec `json:"spec,omitempty"`
Status DataTypeStatus `json:"status,omitempty"`
}
DataType is the Schema for the datatypes API +k8s:openapi-gen=true
func (*DataType) DeepCopy ¶ added in v0.12.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DataType.
func (*DataType) DeepCopyInto ¶ added in v0.12.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DataType) DeepCopyObject ¶ added in v0.12.0
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DataTypeList ¶ added in v0.12.0
type DataTypeList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []DataType `json:"items"`
}
DataTypeList contains a list of DataType
func (*DataTypeList) DeepCopy ¶ added in v0.12.0
func (in *DataTypeList) DeepCopy() *DataTypeList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DataTypeList.
func (*DataTypeList) DeepCopyInto ¶ added in v0.12.0
func (in *DataTypeList) DeepCopyInto(out *DataTypeList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DataTypeList) DeepCopyObject ¶ added in v0.12.0
func (in *DataTypeList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DataTypeSchema ¶ added in v0.12.0
type DataTypeSchema struct {
Cassandra *CassandraDataTypeSchema `json:"cassandra,omitempty" yaml:"cassandra,omitempty"`
}
func (*DataTypeSchema) DeepCopy ¶ added in v0.12.0
func (in *DataTypeSchema) DeepCopy() *DataTypeSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DataTypeSchema.
func (*DataTypeSchema) DeepCopyInto ¶ added in v0.12.0
func (in *DataTypeSchema) DeepCopyInto(out *DataTypeSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DataTypeSpec ¶ added in v0.12.0
type DataTypeSpec struct {
Database string `json:"database" yaml:"database"`
Name string `json:"name" yaml:"name"`
Schema *DataTypeSchema `json:"schema,omitempty" yaml:"schema,omitempty"`
}
DataTypeSpec defines the desired state of Type
func (*DataTypeSpec) DeepCopy ¶ added in v0.12.0
func (in *DataTypeSpec) DeepCopy() *DataTypeSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DataTypeSpec.
func (*DataTypeSpec) DeepCopyInto ¶ added in v0.12.0
func (in *DataTypeSpec) DeepCopyInto(out *DataTypeSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DataTypeStatus ¶ added in v0.12.0
type DataTypeStatus struct {
}
DataTypeStatus defines the observed state of Type
func (*DataTypeStatus) DeepCopy ¶ added in v0.12.0
func (in *DataTypeStatus) DeepCopy() *DataTypeStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DataTypeStatus.
func (*DataTypeStatus) DeepCopyInto ¶ added in v0.12.0
func (in *DataTypeStatus) DeepCopyInto(out *DataTypeStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Migration ¶
type Migration struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec MigrationSpec `json:"spec,omitempty"`
Status MigrationStatus `json:"status,omitempty"`
}
Migration is the Schema for the migrations API +kubebuilder:printcolumn:name="Database",type=string,JSONPath=`.spec.databaseName` +kubebuilder:printcolumn:name="Table",type=string,JSONPath=`.spec.tableName` +kubebuilder:printcolumn:name="Namespace",type=string,JSONPath=`.metadata.namespace`,priority=1 +kubebuilder:printcolumn:name="Phase",type=string,JSONPath=`.status.phase` +kubebuilder:printcolumn:name="Age",type="date",JSONPath=".metadata.creationTimestamp" +k8s:openapi-gen=true
func (*Migration) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Migration.
func (*Migration) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Migration) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MigrationList ¶
type MigrationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Migration `json:"items"`
}
MigrationList contains a list of Migration
func (*MigrationList) DeepCopy ¶
func (in *MigrationList) DeepCopy() *MigrationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MigrationList.
func (*MigrationList) DeepCopyInto ¶
func (in *MigrationList) DeepCopyInto(out *MigrationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MigrationList) DeepCopyObject ¶
func (in *MigrationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MigrationSpec ¶
type MigrationSpec struct {
DatabaseName string `json:"databaseName,omitempty"`
TableName string `json:"tableName"`
TableNamespace string `json:"tableNamespace"`
GeneratedDDL string `json:"generatedDDL,omitempty"`
EditedDDL string `json:"editedDDL,omitempty"`
}
MigrationSpec defines the desired state of Migration
func (*MigrationSpec) DeepCopy ¶
func (in *MigrationSpec) DeepCopy() *MigrationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MigrationSpec.
func (*MigrationSpec) DeepCopyInto ¶
func (in *MigrationSpec) DeepCopyInto(out *MigrationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MigrationStatus ¶
type MigrationStatus struct {
Phase Phase `json:"phase,omitempty"`
// PlannedAt is the unix nano timestamp when the plan was generated
PlannedAt int64 `json:"plannedAt,omitempty"`
// InvalidatedAt is the unix nano timestamp when this plan was determined to be invalid or outdated
InvalidatedAt int64 `json:"invalidatedAt,omitempty"`
ApprovedAt int64 `json:"approvedAt,omitempty"`
RejectedAt int64 `json:"rejectedAt,omitempty"`
ExecutedAt int64 `json:"executedAt,omitempty"`
}
MigrationStatus defines the observed state of Migration
func (*MigrationStatus) DeepCopy ¶
func (in *MigrationStatus) DeepCopy() *MigrationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MigrationStatus.
func (*MigrationStatus) DeepCopyInto ¶
func (in *MigrationStatus) DeepCopyInto(out *MigrationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MysqlTableColumn ¶ added in v0.12.0
type MysqlTableColumn struct {
Name string `json:"name" yaml:"name"`
Type string `json:"type" yaml:"type"`
Constraints *MysqlTableColumnConstraints `json:"constraints,omitempty" yaml:"constraints,omitempty"`
Attributes *MysqlTableColumnAttributes `json:"attributes,omitempty" yaml:"attributes,omitempty"`
Default *string `json:"default,omitempty" yaml:"default,omitempty"`
Charset string `json:"charset,omitempty" yaml:"charset,omitempty"`
Collation string `json:"collation,omitempty" yaml:"collation,omitempty"`
}
func (*MysqlTableColumn) DeepCopy ¶ added in v0.12.0
func (in *MysqlTableColumn) DeepCopy() *MysqlTableColumn
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MysqlTableColumn.
func (*MysqlTableColumn) DeepCopyInto ¶ added in v0.12.0
func (in *MysqlTableColumn) DeepCopyInto(out *MysqlTableColumn)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MysqlTableColumnAttributes ¶ added in v0.12.0
type MysqlTableColumnAttributes struct {
AutoIncrement *bool `json:"autoIncrement,omitempty" yaml:"autoIncrement,omitempty"`
}
func (*MysqlTableColumnAttributes) DeepCopy ¶ added in v0.12.0
func (in *MysqlTableColumnAttributes) DeepCopy() *MysqlTableColumnAttributes
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MysqlTableColumnAttributes.
func (*MysqlTableColumnAttributes) DeepCopyInto ¶ added in v0.12.0
func (in *MysqlTableColumnAttributes) DeepCopyInto(out *MysqlTableColumnAttributes)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MysqlTableColumnConstraints ¶ added in v0.12.0
type MysqlTableColumnConstraints struct {
NotNull *bool `json:"notNull,omitempty" yaml:"notNull,omitempty"`
}
func (*MysqlTableColumnConstraints) DeepCopy ¶ added in v0.12.0
func (in *MysqlTableColumnConstraints) DeepCopy() *MysqlTableColumnConstraints
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MysqlTableColumnConstraints.
func (*MysqlTableColumnConstraints) DeepCopyInto ¶ added in v0.12.0
func (in *MysqlTableColumnConstraints) DeepCopyInto(out *MysqlTableColumnConstraints)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MysqlTableForeignKey ¶ added in v0.12.0
type MysqlTableForeignKey struct {
Columns []string `json:"columns" yaml:"columns"`
References MysqlTableForeignKeyReferences `json:"references" yaml:"references"`
OnDelete string `json:"onDelete,omitempty" yaml:"onDelete,omitempty"`
Name string `json:"name,omitempty" yaml:"name,omitempty"`
}
func (*MysqlTableForeignKey) DeepCopy ¶ added in v0.12.0
func (in *MysqlTableForeignKey) DeepCopy() *MysqlTableForeignKey
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MysqlTableForeignKey.
func (*MysqlTableForeignKey) DeepCopyInto ¶ added in v0.12.0
func (in *MysqlTableForeignKey) DeepCopyInto(out *MysqlTableForeignKey)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MysqlTableForeignKeyReferences ¶ added in v0.12.0
type MysqlTableForeignKeyReferences struct {
Table string `json:"table"`
Columns []string `json:"columns"`
}
func (*MysqlTableForeignKeyReferences) DeepCopy ¶ added in v0.12.0
func (in *MysqlTableForeignKeyReferences) DeepCopy() *MysqlTableForeignKeyReferences
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MysqlTableForeignKeyReferences.
func (*MysqlTableForeignKeyReferences) DeepCopyInto ¶ added in v0.12.0
func (in *MysqlTableForeignKeyReferences) DeepCopyInto(out *MysqlTableForeignKeyReferences)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MysqlTableIndex ¶ added in v0.12.0
type MysqlTableIndex struct {
Columns []string `json:"columns" yaml:"columns"`
Name string `json:"name,omitempty" yaml:"name,omitempty"`
IsUnique bool `json:"isUnique,omitempty" yaml:"isUnique,omitempty"`
Type string `json:"type,omitempty" yaml:"type,omitempty"`
}
func (*MysqlTableIndex) DeepCopy ¶ added in v0.12.0
func (in *MysqlTableIndex) DeepCopy() *MysqlTableIndex
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MysqlTableIndex.
func (*MysqlTableIndex) DeepCopyInto ¶ added in v0.12.0
func (in *MysqlTableIndex) DeepCopyInto(out *MysqlTableIndex)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MysqlTableSchema ¶ added in v0.12.0
type MysqlTableSchema struct {
PrimaryKey []string `json:"primaryKey,omitempty" yaml:"primaryKey,omitempty"`
ForeignKeys []*MysqlTableForeignKey `json:"foreignKeys,omitempty" yaml:"foreignKeys,omitempty"`
Indexes []*MysqlTableIndex `json:"indexes,omitempty" yaml:"indexes,omitempty"`
Columns []*MysqlTableColumn `json:"columns,omitempty" yaml:"columns,omitempty"`
IsDeleted bool `json:"isDeleted,omitempty" yaml:"isDeleted,omitempty"`
DefaultCharset string `json:"defaultCharset,omitempty" yaml:"defaultCharset,omitempty"`
Collation string `json:"collation,omitempty" yaml:"collation,omitempty"`
}
func (*MysqlTableSchema) DeepCopy ¶ added in v0.12.0
func (in *MysqlTableSchema) DeepCopy() *MysqlTableSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MysqlTableSchema.
func (*MysqlTableSchema) DeepCopyInto ¶ added in v0.12.0
func (in *MysqlTableSchema) DeepCopyInto(out *MysqlTableSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NotImplementedViewSchema ¶ added in v0.15.0
type NotImplementedViewSchema struct {
}
func (*NotImplementedViewSchema) DeepCopy ¶ added in v0.15.0
func (in *NotImplementedViewSchema) DeepCopy() *NotImplementedViewSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NotImplementedViewSchema.
func (*NotImplementedViewSchema) DeepCopyInto ¶ added in v0.15.0
func (in *NotImplementedViewSchema) DeepCopyInto(out *NotImplementedViewSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Phase ¶ added in v0.12.7
type Phase string
+kubebuilder:validation:Enum=PLANNED;APPROVED;EXECUTED;INVALID;REJECTED
type PostgresqlTableColumn ¶ added in v0.12.0
type PostgresqlTableColumn struct {
Name string `json:"name" yaml:"name"`
Type string `json:"type" yaml:"type"`
Constraints *PostgresqlTableColumnConstraints `json:"constraints,omitempty" yaml:"constraints,omitempty"`
Attributes *PostgresqlTableColumnAttributes `json:"attributes,omitempty" yaml:"attributes,omitempty"`
Default *string `json:"default,omitempty" yaml:"default,omitempty"`
}
func (*PostgresqlTableColumn) DeepCopy ¶ added in v0.12.0
func (in *PostgresqlTableColumn) DeepCopy() *PostgresqlTableColumn
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PostgresqlTableColumn.
func (*PostgresqlTableColumn) DeepCopyInto ¶ added in v0.12.0
func (in *PostgresqlTableColumn) DeepCopyInto(out *PostgresqlTableColumn)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PostgresqlTableColumnAttributes ¶ added in v0.12.0
type PostgresqlTableColumnAttributes struct {
AutoIncrement *bool `json:"autoIncrement,omitempty" yaml:"autoIncrement,omitempty"`
}
func (*PostgresqlTableColumnAttributes) DeepCopy ¶ added in v0.12.0
func (in *PostgresqlTableColumnAttributes) DeepCopy() *PostgresqlTableColumnAttributes
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PostgresqlTableColumnAttributes.
func (*PostgresqlTableColumnAttributes) DeepCopyInto ¶ added in v0.12.0
func (in *PostgresqlTableColumnAttributes) DeepCopyInto(out *PostgresqlTableColumnAttributes)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PostgresqlTableColumnConstraints ¶ added in v0.12.0
type PostgresqlTableColumnConstraints struct {
NotNull *bool `json:"notNull,omitempty" yaml:"notNull,omitempty"`
}
func (*PostgresqlTableColumnConstraints) DeepCopy ¶ added in v0.12.0
func (in *PostgresqlTableColumnConstraints) DeepCopy() *PostgresqlTableColumnConstraints
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PostgresqlTableColumnConstraints.
func (*PostgresqlTableColumnConstraints) DeepCopyInto ¶ added in v0.12.0
func (in *PostgresqlTableColumnConstraints) DeepCopyInto(out *PostgresqlTableColumnConstraints)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PostgresqlTableForeignKey ¶ added in v0.12.0
type PostgresqlTableForeignKey struct {
Columns []string `json:"columns" yaml:"columns"`
References PostgresqlTableForeignKeyReferences `json:"references" yaml:"references"`
OnDelete string `json:"onDelete,omitempty" yaml:"onDelete,omitempty"`
Name string `json:"name,omitempty" yaml:"name,omitempty"`
}
func (*PostgresqlTableForeignKey) DeepCopy ¶ added in v0.12.0
func (in *PostgresqlTableForeignKey) DeepCopy() *PostgresqlTableForeignKey
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PostgresqlTableForeignKey.
func (*PostgresqlTableForeignKey) DeepCopyInto ¶ added in v0.12.0
func (in *PostgresqlTableForeignKey) DeepCopyInto(out *PostgresqlTableForeignKey)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PostgresqlTableForeignKeyReferences ¶ added in v0.12.0
type PostgresqlTableForeignKeyReferences struct {
Table string `json:"table"`
Columns []string `json:"columns"`
}
func (*PostgresqlTableForeignKeyReferences) DeepCopy ¶ added in v0.12.0
func (in *PostgresqlTableForeignKeyReferences) DeepCopy() *PostgresqlTableForeignKeyReferences
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PostgresqlTableForeignKeyReferences.
func (*PostgresqlTableForeignKeyReferences) DeepCopyInto ¶ added in v0.12.0
func (in *PostgresqlTableForeignKeyReferences) DeepCopyInto(out *PostgresqlTableForeignKeyReferences)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PostgresqlTableIndex ¶ added in v0.12.0
type PostgresqlTableIndex struct {
Columns []string `json:"columns" yaml:"columns"`
Name string `json:"name,omitempty" yaml:"name,omitempty"`
IsUnique bool `json:"isUnique,omitempty" yaml:"isUnique,omitempty"`
Type string `json:"type,omitempty" yaml:"type,omitempty"`
}
func (*PostgresqlTableIndex) DeepCopy ¶ added in v0.12.0
func (in *PostgresqlTableIndex) DeepCopy() *PostgresqlTableIndex
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PostgresqlTableIndex.
func (*PostgresqlTableIndex) DeepCopyInto ¶ added in v0.12.0
func (in *PostgresqlTableIndex) DeepCopyInto(out *PostgresqlTableIndex)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PostgresqlTableSchema ¶ added in v0.12.0
type PostgresqlTableSchema struct {
PrimaryKey []string `json:"primaryKey,omitempty" yaml:"primaryKey,omitempty"`
ForeignKeys []*PostgresqlTableForeignKey `json:"foreignKeys,omitempty" yaml:"foreignKeys,omitempty"`
Indexes []*PostgresqlTableIndex `json:"indexes,omitempty" yaml:"indexes,omitempty"`
Columns []*PostgresqlTableColumn `json:"columns,omitempty" yaml:"columns,omitempty"`
IsDeleted bool `json:"isDeleted,omitempty" yaml:"isDeleted,omitempty"`
Triggers []*PostgresqlTableTrigger `json:"json:triggers,omitempty" yaml:"triggers,omitempty"`
}
func (*PostgresqlTableSchema) DeepCopy ¶ added in v0.12.0
func (in *PostgresqlTableSchema) DeepCopy() *PostgresqlTableSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PostgresqlTableSchema.
func (*PostgresqlTableSchema) DeepCopyInto ¶ added in v0.12.0
func (in *PostgresqlTableSchema) DeepCopyInto(out *PostgresqlTableSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PostgresqlTableTrigger ¶ added in v0.12.0
type PostgresqlTableTrigger struct {
Name string `json:"name,omitempty" yaml:"name,omitempty"`
ConstraintTrigger *bool `json:"constraintTrigger,omitempty" yaml:"constraintTrigger,omitempty"`
Events []string `json:"events" yaml:"events"`
ForEachStatement *bool `json:"forEachStatement,omitempty" yaml:"forEachStatement,omitempty"`
ForEachRow *bool `json:"forEachRun,omitempty" yaml:"forEachRow,omitempty"`
Condition *string `json:"condition,omitempty" yaml:"condition,omitempty"`
ExecuteProcedure string `json:"executeProcedure" yaml:"executeProcedure"`
Arguments []string `json:"arguments,omitempty" yaml:"arguments,omitempty"`
}
func (*PostgresqlTableTrigger) DeepCopy ¶ added in v0.12.0
func (in *PostgresqlTableTrigger) DeepCopy() *PostgresqlTableTrigger
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PostgresqlTableTrigger.
func (*PostgresqlTableTrigger) DeepCopyInto ¶ added in v0.12.0
func (in *PostgresqlTableTrigger) DeepCopyInto(out *PostgresqlTableTrigger)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RqliteTableColumn ¶ added in v0.13.3
type RqliteTableColumn struct {
Name string `json:"name" yaml:"name"`
Type string `json:"type" yaml:"type"`
Constraints *RqliteTableColumnConstraints `json:"constraints,omitempty" yaml:"constraints,omitempty"`
Attributes *RqliteTableColumnAttributes `json:"attributes,omitempty" yaml:"attributes,omitempty"`
Default *string `json:"default,omitempty" yaml:"default,omitempty"`
}
func (*RqliteTableColumn) DeepCopy ¶ added in v0.13.3
func (in *RqliteTableColumn) DeepCopy() *RqliteTableColumn
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RqliteTableColumn.
func (*RqliteTableColumn) DeepCopyInto ¶ added in v0.13.3
func (in *RqliteTableColumn) DeepCopyInto(out *RqliteTableColumn)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RqliteTableColumnAttributes ¶ added in v0.13.3
type RqliteTableColumnAttributes struct {
AutoIncrement *bool `json:"autoIncrement,omitempty" yaml:"autoIncrement,omitempty"`
}
func (*RqliteTableColumnAttributes) DeepCopy ¶ added in v0.13.3
func (in *RqliteTableColumnAttributes) DeepCopy() *RqliteTableColumnAttributes
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RqliteTableColumnAttributes.
func (*RqliteTableColumnAttributes) DeepCopyInto ¶ added in v0.13.3
func (in *RqliteTableColumnAttributes) DeepCopyInto(out *RqliteTableColumnAttributes)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RqliteTableColumnConstraints ¶ added in v0.13.3
type RqliteTableColumnConstraints struct {
NotNull *bool `json:"notNull,omitempty" yaml:"notNull,omitempty"`
}
func (*RqliteTableColumnConstraints) DeepCopy ¶ added in v0.13.3
func (in *RqliteTableColumnConstraints) DeepCopy() *RqliteTableColumnConstraints
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RqliteTableColumnConstraints.
func (*RqliteTableColumnConstraints) DeepCopyInto ¶ added in v0.13.3
func (in *RqliteTableColumnConstraints) DeepCopyInto(out *RqliteTableColumnConstraints)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RqliteTableForeignKey ¶ added in v0.13.3
type RqliteTableForeignKey struct {
Columns []string `json:"columns" yaml:"columns"`
References RqliteTableForeignKeyReferences `json:"references" yaml:"references"`
OnDelete string `json:"onDelete,omitempty" yaml:"onDelete,omitempty"`
Name string `json:"name,omitempty" yaml:"name,omitempty"`
}
func (*RqliteTableForeignKey) DeepCopy ¶ added in v0.13.3
func (in *RqliteTableForeignKey) DeepCopy() *RqliteTableForeignKey
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RqliteTableForeignKey.
func (*RqliteTableForeignKey) DeepCopyInto ¶ added in v0.13.3
func (in *RqliteTableForeignKey) DeepCopyInto(out *RqliteTableForeignKey)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RqliteTableForeignKeyReferences ¶ added in v0.13.3
type RqliteTableForeignKeyReferences struct {
Table string `json:"table"`
Columns []string `json:"columns"`
}
func (*RqliteTableForeignKeyReferences) DeepCopy ¶ added in v0.13.3
func (in *RqliteTableForeignKeyReferences) DeepCopy() *RqliteTableForeignKeyReferences
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RqliteTableForeignKeyReferences.
func (*RqliteTableForeignKeyReferences) DeepCopyInto ¶ added in v0.13.3
func (in *RqliteTableForeignKeyReferences) DeepCopyInto(out *RqliteTableForeignKeyReferences)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RqliteTableIndex ¶ added in v0.13.3
type RqliteTableIndex struct {
Columns []string `json:"columns" yaml:"columns"`
Name string `json:"name,omitempty" yaml:"name,omitempty"`
IsUnique bool `json:"isUnique,omitempty" yaml:"isUnique,omitempty"`
Type string `json:"type,omitempty" yaml:"type,omitempty"`
}
func (*RqliteTableIndex) DeepCopy ¶ added in v0.13.3
func (in *RqliteTableIndex) DeepCopy() *RqliteTableIndex
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RqliteTableIndex.
func (*RqliteTableIndex) DeepCopyInto ¶ added in v0.13.3
func (in *RqliteTableIndex) DeepCopyInto(out *RqliteTableIndex)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RqliteTableSchema ¶ added in v0.13.3
type RqliteTableSchema struct {
PrimaryKey []string `json:"primaryKey,omitempty" yaml:"primaryKey,omitempty"`
ForeignKeys []*RqliteTableForeignKey `json:"foreignKeys,omitempty" yaml:"foreignKeys,omitempty"`
Indexes []*RqliteTableIndex `json:"indexes,omitempty" yaml:"indexes,omitempty"`
Columns []*RqliteTableColumn `json:"columns,omitempty" yaml:"columns,omitempty"`
IsDeleted bool `json:"isDeleted,omitempty" yaml:"isDeleted,omitempty"`
Strict bool `json:"strict,omitempty" yaml:"strict,omitempty"`
}
func (*RqliteTableSchema) DeepCopy ¶ added in v0.13.3
func (in *RqliteTableSchema) DeepCopy() *RqliteTableSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RqliteTableSchema.
func (*RqliteTableSchema) DeepCopyInto ¶ added in v0.13.3
func (in *RqliteTableSchema) DeepCopyInto(out *RqliteTableSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SeedData ¶ added in v0.13.0
type SeedData struct {
Rows []SeedDataRow `json:"rows" yaml:"rows"`
}
func (*SeedData) DeepCopy ¶ added in v0.13.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SeedData.
func (*SeedData) DeepCopyInto ¶ added in v0.13.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SeedDataRow ¶ added in v0.13.0
type SeedDataRow struct {
Columns []Column `json:"columns" yaml:"columns"`
}
func (*SeedDataRow) DeepCopy ¶ added in v0.13.0
func (in *SeedDataRow) DeepCopy() *SeedDataRow
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SeedDataRow.
func (*SeedDataRow) DeepCopyInto ¶ added in v0.13.0
func (in *SeedDataRow) DeepCopyInto(out *SeedDataRow)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SeedDataValue ¶ added in v0.13.0
type SeedDataValue struct {
Int *int `json:"int,omitempty" yaml:"int,omitempty"`
Str *string `json:"str,omitempty" yaml:"str,omitempty"`
}
func (*SeedDataValue) DeepCopy ¶ added in v0.13.0
func (in *SeedDataValue) DeepCopy() *SeedDataValue
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SeedDataValue.
func (*SeedDataValue) DeepCopyInto ¶ added in v0.13.0
func (in *SeedDataValue) DeepCopyInto(out *SeedDataValue)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SqliteTableColumn ¶ added in v0.12.0
type SqliteTableColumn struct {
Name string `json:"name" yaml:"name"`
Type string `json:"type" yaml:"type"`
Constraints *SqliteTableColumnConstraints `json:"constraints,omitempty" yaml:"constraints,omitempty"`
Attributes *SqliteTableColumnAttributes `json:"attributes,omitempty" yaml:"attributes,omitempty"`
Default *string `json:"default,omitempty" yaml:"default,omitempty"`
}
func (*SqliteTableColumn) DeepCopy ¶ added in v0.12.0
func (in *SqliteTableColumn) DeepCopy() *SqliteTableColumn
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SqliteTableColumn.
func (*SqliteTableColumn) DeepCopyInto ¶ added in v0.12.0
func (in *SqliteTableColumn) DeepCopyInto(out *SqliteTableColumn)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SqliteTableColumnAttributes ¶ added in v0.12.0
type SqliteTableColumnAttributes struct {
AutoIncrement *bool `json:"autoIncrement,omitempty" yaml:"autoIncrement,omitempty"`
}
func (*SqliteTableColumnAttributes) DeepCopy ¶ added in v0.12.0
func (in *SqliteTableColumnAttributes) DeepCopy() *SqliteTableColumnAttributes
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SqliteTableColumnAttributes.
func (*SqliteTableColumnAttributes) DeepCopyInto ¶ added in v0.12.0
func (in *SqliteTableColumnAttributes) DeepCopyInto(out *SqliteTableColumnAttributes)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SqliteTableColumnConstraints ¶ added in v0.12.0
type SqliteTableColumnConstraints struct {
NotNull *bool `json:"notNull,omitempty" yaml:"notNull,omitempty"`
}
func (*SqliteTableColumnConstraints) DeepCopy ¶ added in v0.12.0
func (in *SqliteTableColumnConstraints) DeepCopy() *SqliteTableColumnConstraints
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SqliteTableColumnConstraints.
func (*SqliteTableColumnConstraints) DeepCopyInto ¶ added in v0.12.0
func (in *SqliteTableColumnConstraints) DeepCopyInto(out *SqliteTableColumnConstraints)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SqliteTableForeignKey ¶ added in v0.12.0
type SqliteTableForeignKey struct {
Columns []string `json:"columns" yaml:"columns"`
References SqliteTableForeignKeyReferences `json:"references" yaml:"references"`
OnDelete string `json:"onDelete,omitempty" yaml:"onDelete,omitempty"`
Name string `json:"name,omitempty" yaml:"name,omitempty"`
}
func (*SqliteTableForeignKey) DeepCopy ¶ added in v0.12.0
func (in *SqliteTableForeignKey) DeepCopy() *SqliteTableForeignKey
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SqliteTableForeignKey.
func (*SqliteTableForeignKey) DeepCopyInto ¶ added in v0.12.0
func (in *SqliteTableForeignKey) DeepCopyInto(out *SqliteTableForeignKey)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SqliteTableForeignKeyReferences ¶ added in v0.12.0
type SqliteTableForeignKeyReferences struct {
Table string `json:"table"`
Columns []string `json:"columns"`
}
func (*SqliteTableForeignKeyReferences) DeepCopy ¶ added in v0.12.0
func (in *SqliteTableForeignKeyReferences) DeepCopy() *SqliteTableForeignKeyReferences
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SqliteTableForeignKeyReferences.
func (*SqliteTableForeignKeyReferences) DeepCopyInto ¶ added in v0.12.0
func (in *SqliteTableForeignKeyReferences) DeepCopyInto(out *SqliteTableForeignKeyReferences)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SqliteTableIndex ¶ added in v0.12.0
type SqliteTableIndex struct {
Columns []string `json:"columns" yaml:"columns"`
Name string `json:"name,omitempty" yaml:"name,omitempty"`
IsUnique bool `json:"isUnique,omitempty" yaml:"isUnique,omitempty"`
Type string `json:"type,omitempty" yaml:"type,omitempty"`
}
func (*SqliteTableIndex) DeepCopy ¶ added in v0.12.0
func (in *SqliteTableIndex) DeepCopy() *SqliteTableIndex
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SqliteTableIndex.
func (*SqliteTableIndex) DeepCopyInto ¶ added in v0.12.0
func (in *SqliteTableIndex) DeepCopyInto(out *SqliteTableIndex)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SqliteTableSchema ¶ added in v0.12.0
type SqliteTableSchema struct {
PrimaryKey []string `json:"primaryKey,omitempty" yaml:"primaryKey,omitempty"`
ForeignKeys []*SqliteTableForeignKey `json:"foreignKeys,omitempty" yaml:"foreignKeys,omitempty"`
Indexes []*SqliteTableIndex `json:"indexes,omitempty" yaml:"indexes,omitempty"`
Columns []*SqliteTableColumn `json:"columns,omitempty" yaml:"columns,omitempty"`
IsDeleted bool `json:"isDeleted,omitempty" yaml:"isDeleted,omitempty"`
Strict bool `json:"strict,omitempty" yaml:"strict,omitempty"`
}
func (*SqliteTableSchema) DeepCopy ¶ added in v0.12.0
func (in *SqliteTableSchema) DeepCopy() *SqliteTableSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SqliteTableSchema.
func (*SqliteTableSchema) DeepCopyInto ¶ added in v0.12.0
func (in *SqliteTableSchema) DeepCopyInto(out *SqliteTableSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Table ¶
type Table struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec TableSpec `json:"spec,omitempty"`
Status TableStatus `json:"status,omitempty"`
}
Table is the Schema for the tables API +kubebuilder:printcolumn:name="Namespace",type=string,JSONPath=`.metadata.namespace`,priority=1 +kubebuilder:printcolumn:name="Table",type=string,JSONPath=`.spec.name` +kubebuilder:printcolumn:name="Database",type=string,JSONPath=`.spec.database` +kubebuilder:printcolumn:name="Age",type="date",JSONPath=".metadata.creationTimestamp" +k8s:openapi-gen=true
func (*Table) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Table.
func (*Table) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Table) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TableList ¶
type TableList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Table `json:"items"`
}
TableList contains a list of Table
func (*TableList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TableList.
func (*TableList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TableList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TableSchema ¶
type TableSchema struct {
Postgres *PostgresqlTableSchema `json:"postgres,omitempty" yaml:"postgres,omitempty"`
Mysql *MysqlTableSchema `json:"mysql,omitempty" yaml:"mysql,omitempty"`
CockroachDB *PostgresqlTableSchema `json:"cockroachdb,omitempty" yaml:"cockroachdb,omitempty"`
Cassandra *CassandraTableSchema `json:"cassandra,omitempty" yaml:"cassandra,omitempty"`
TimescaleDB *TimescaleDBTableSchema `json:"timescaledb,omitempty" yaml:"timescaledb,omitempty"`
SQLite *SqliteTableSchema `json:"sqlite,omitempty" yaml:"sqlite,omitempty"`
RQLite *RqliteTableSchema `json:"rqlite,omitempty" yaml:"rqlite,omitempty"`
}
func (*TableSchema) DeepCopy ¶
func (in *TableSchema) DeepCopy() *TableSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TableSchema.
func (*TableSchema) DeepCopyInto ¶
func (in *TableSchema) DeepCopyInto(out *TableSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TableSpec ¶
type TableSpec struct {
Database string `json:"database" yaml:"database"`
Name string `json:"name" yaml:"name"`
Requires []string `json:"requires,omitempty" yaml:"requires,omitempty"`
Schema *TableSchema `json:"schema,omitempty" yaml:"schema,omitempty"`
SeedData *SeedData `json:"seedData,omitempty" yaml:"seedData,omitempty"`
}
TableSpec defines the desired state of Table
func (*TableSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TableSpec.
func (*TableSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TableStatus ¶
type TableStatus struct {
// We store the SHA of the table spec from the last time we executed a plan to
// make startup less noisy by skipping re-planning objects that have been planned
// we cannot use the resourceVersion or generation fields because updating them
// would cause the object to be modified again
LastPlannedTableSpecSHA string `json:"lastPlannedTableSpecSHA,omitempty" yaml:"lastPlannedTableSpecSHA,omitempty"`
}
TableStatus defines the observed state of Table
func (*TableStatus) DeepCopy ¶
func (in *TableStatus) DeepCopy() *TableStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TableStatus.
func (*TableStatus) DeepCopyInto ¶
func (in *TableStatus) DeepCopyInto(out *TableStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TimescaleDBCompression ¶ added in v0.15.0
type TimescaleDBCompression struct {
SegmentBy *string `json:"segmentBy" yaml:"segmentBy"`
Interval *string `json:"interval" yaml:"interval"`
}
func (*TimescaleDBCompression) DeepCopy ¶ added in v0.15.0
func (in *TimescaleDBCompression) DeepCopy() *TimescaleDBCompression
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TimescaleDBCompression.
func (*TimescaleDBCompression) DeepCopyInto ¶ added in v0.15.0
func (in *TimescaleDBCompression) DeepCopyInto(out *TimescaleDBCompression)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TimescaleDBHypertable ¶ added in v0.15.0
type TimescaleDBHypertable struct {
TimeColumnName *string `json:"timeColumnName,omitempty" yaml:"timeColumnName,omitempty"`
PartitioningColumn *string `json:"partitioningColumn,omitempty" yaml:"partitioningColumn,omitempty"`
NumberPartitions *int `json:"numberPartitions,omitempty" yaml:"numberPartitions,omitempty"`
ChunkTimeInterval *string `json:"chunkTimeInterval,omitempty" yaml:"chunkTimeInterval,omitempty"`
CreateDefaultIndexes *bool `json:"createDefaultIndexes,omitempty" yaml:"createDefaultIndexes,omitempty"`
IfNotExists *bool `json:"ifNotExists,omitempty" yaml:"ifNotExists,omitempty"`
PartitioningFunc *string `json:"partitioningFunc,omitempty" yaml:"partitioningFunc,omitempty"`
AssociatedSchemaName *string `json:"associatedSchemaName,omitempty" yaml:"associatedSchemaName,omitempty"`
AssociatedTablePrefix *string `json:"associatedTablePrefix,omitempty" yaml:"associatedTablePrefix,omitempty"`
MigrateData *bool `json:"migrateData,omitempty" yaml:"migrateData,omitempty"`
TimePartitioningFunc *string `json:"timePartitioningFunc,omitempty" yaml:"timePartitioningFunc,omitempty"`
ReplicationFactor *int `json:"replicationFactor,omitempty" yaml:"replicationFactor,omitempty"`
DataNodes []string `json:"dataNodes,omitempty" yaml:"dataNodes,omitempty"`
Compression *TimescaleDBCompression `json:"compression,omitempty" yaml:"compression,omitempty"`
Retention *TimescaleDBRetention `json:"retention,omitempty" yaml:"retention,omitempty"`
}
func (*TimescaleDBHypertable) DeepCopy ¶ added in v0.15.0
func (in *TimescaleDBHypertable) DeepCopy() *TimescaleDBHypertable
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TimescaleDBHypertable.
func (*TimescaleDBHypertable) DeepCopyInto ¶ added in v0.15.0
func (in *TimescaleDBHypertable) DeepCopyInto(out *TimescaleDBHypertable)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TimescaleDBRetention ¶ added in v0.15.0
type TimescaleDBRetention struct {
Interval string `json:"interval" yaml:"interval"`
}
func (*TimescaleDBRetention) DeepCopy ¶ added in v0.15.0
func (in *TimescaleDBRetention) DeepCopy() *TimescaleDBRetention
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TimescaleDBRetention.
func (*TimescaleDBRetention) DeepCopyInto ¶ added in v0.15.0
func (in *TimescaleDBRetention) DeepCopyInto(out *TimescaleDBRetention)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TimescaleDBTableSchema ¶ added in v0.15.0
type TimescaleDBTableSchema struct {
PrimaryKey []string `json:"primaryKey,omitempty" yaml:"primaryKey,omitempty"`
ForeignKeys []*PostgresqlTableForeignKey `json:"foreignKeys,omitempty" yaml:"foreignKeys,omitempty"`
Indexes []*PostgresqlTableIndex `json:"indexes,omitempty" yaml:"indexes,omitempty"`
Columns []*PostgresqlTableColumn `json:"columns,omitempty" yaml:"columns,omitempty"`
IsDeleted bool `json:"isDeleted,omitempty" yaml:"isDeleted,omitempty"`
Triggers []*PostgresqlTableTrigger `json:"triggers,omitempty" yaml:"triggers,omitempty"`
Hypertable *TimescaleDBHypertable `json:"hypertable,omitempty" yaml:"hypertable,omitempty"`
}
func (*TimescaleDBTableSchema) DeepCopy ¶ added in v0.15.0
func (in *TimescaleDBTableSchema) DeepCopy() *TimescaleDBTableSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TimescaleDBTableSchema.
func (*TimescaleDBTableSchema) DeepCopyInto ¶ added in v0.15.0
func (in *TimescaleDBTableSchema) DeepCopyInto(out *TimescaleDBTableSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TimescaleDBViewSchema ¶ added in v0.15.0
type TimescaleDBViewSchema struct {
IsContinuousAggregate *bool `json:"isContinuousAggregate,omitempty" yaml:"isContinuousAggregate,omitempty"`
WithNoData *bool `json:"withNoData,omitempty" yaml:"withNoData,omitempty"`
Query string `json:"query,omitempty" yaml:"query,omitempty"`
IsDeleted bool `json:"isDeleted,omitempty" yaml:"isDeleted,omitempty"`
}
func (*TimescaleDBViewSchema) DeepCopy ¶ added in v0.15.0
func (in *TimescaleDBViewSchema) DeepCopy() *TimescaleDBViewSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TimescaleDBViewSchema.
func (*TimescaleDBViewSchema) DeepCopyInto ¶ added in v0.15.0
func (in *TimescaleDBViewSchema) DeepCopyInto(out *TimescaleDBViewSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type View ¶ added in v0.15.0
type View struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ViewSpec `json:"spec,omitempty"`
Status ViewStatus `json:"status,omitempty"`
}
View is the Schema for the view API +kubebuilder:printcolumn:name="Namespace",type=string,JSONPath=`.metadata.namespace`,priority=1 +kubebuilder:printcolumn:name="View",type=string,JSONPath=`.spec.name` +kubebuilder:printcolumn:name="Database",type=string,JSONPath=`.spec.database` +kubebuilder:printcolumn:name="Age",type="date",JSONPath=".metadata.creationTimestamp" +k8s:openapi-gen=true
func (*View) DeepCopy ¶ added in v0.15.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new View.
func (*View) DeepCopyInto ¶ added in v0.15.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*View) DeepCopyObject ¶ added in v0.15.0
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ViewList ¶ added in v0.15.0
type ViewList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []View `json:"items"`
}
ViewList contains a list of View
func (*ViewList) DeepCopy ¶ added in v0.15.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ViewList.
func (*ViewList) DeepCopyInto ¶ added in v0.15.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ViewList) DeepCopyObject ¶ added in v0.15.0
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ViewSchema ¶ added in v0.15.0
type ViewSchema struct {
Postgres *NotImplementedViewSchema `json:"postgres,omitempty" yaml:"postgres,omitempty"`
Mysql *NotImplementedViewSchema `json:"mysql,omitempty" yaml:"mysql,omitempty"`
CockroachDB *NotImplementedViewSchema `json:"cockroachdb,omitempty" yaml:"cockroachdb,omitempty"`
RQLite *NotImplementedViewSchema `json:"rqlite,omitempty" yaml:"rqlite,omitempty"`
SQLite *NotImplementedViewSchema `json:"sqlite,omitempty" yaml:"sqlite,omitempty"`
TimescaleDB *TimescaleDBViewSchema `json:"timescaledb,omitempty" yaml:"timescaledb,omitempty"`
Cassandra *NotImplementedViewSchema `json:"cassandra,omitempty" yaml:"cassandra,omitempty"`
}
func (*ViewSchema) DeepCopy ¶ added in v0.15.0
func (in *ViewSchema) DeepCopy() *ViewSchema
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ViewSchema.
func (*ViewSchema) DeepCopyInto ¶ added in v0.15.0
func (in *ViewSchema) DeepCopyInto(out *ViewSchema)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ViewSpec ¶ added in v0.15.0
type ViewSpec struct {
Database string `json:"database" yaml:"database"`
Name string `json:"name" yaml:"name"`
Requires []string `json:"requires,omitempty" yaml:"requires,omitempty"`
Schema *ViewSchema `json:"schema,omitempty" yaml:"schema,omitempty"`
}
ViewSpec defines the desired state of View
func (*ViewSpec) DeepCopy ¶ added in v0.15.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ViewSpec.
func (*ViewSpec) DeepCopyInto ¶ added in v0.15.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ViewStatus ¶ added in v0.15.0
type ViewStatus struct {
// We store the SHA of the view spec from the last time we executed a plan to
// make startup less noisy by skipping re-planning objects that have been planned
// we cannot use the resourceVersion or generation fields because updating them
// would cause the object to be modified again
LastPlannedViewSpecSHA string `json:"lastPlannedViewSpecSHA,omitempty" yaml:"lastPlannedViewSpecSHA,omitempty"`
}
ViewStatus defines the observed state of View
func (*ViewStatus) DeepCopy ¶ added in v0.15.0
func (in *ViewStatus) DeepCopy() *ViewStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ViewStatus.
func (*ViewStatus) DeepCopyInto ¶ added in v0.15.0
func (in *ViewStatus) DeepCopyInto(out *ViewStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.